library("Rsamtools")
library("biomaRt")

ensembl <- useMart("ENSEMBL_MART_ENSEMBL", dataset="hsapiens_gene_ensembl", host="uswest.ensembl.org")

annots <- getBM(attributes=c("ensembl_gene_id", "ensembl_transcript_id", "gene_biotype", "transcript_biotype",
                  "chromosome_name", "start_position", "end_position", "strand", "description", "hgnc_symbol"),
                mart=ensembl)
colnames(annots)[length(colnames(annots))] <- "external_gene_name"

granges <- GRanges(seqnames = annots$chromosome_name,
                   ranges=IRanges(start = annots$start_position, end = annots$end_position),
                   strand = ifelse(annots$strand < 0, "-", "+"))

snornaGR <- granges[annots$transcript_biotype == "snoRNA",]
snohgGenes <- annots[queryHits(findOverlaps(granges, snornaGR, select="all")),"ensembl_gene_id"]
snohgIds <- annots[annots$ensembl_gene_id %in% snohgGenes,"ensembl_transcript_id"]

snrnaGR <- granges[annots$transcript_biotype == "snRNA",]
snhgGenes <- annots[queryHits(findOverlaps(granges, snrnaGR, select="all")),"ensembl_gene_id"]
snhgIds <- annots[annots$ensembl_gene_id %in% snhgGenes,"ensembl_transcript_id"]

miscGenes <- annots[annots$transcript_biotype == "misc_RNA", "ensembl_gene_id"]
miscIds <- annots[annots$ensembl_gene_id %in% miscGenes ,"ensembl_transcript_id"] # & !grepl("^Gm", annots$external_gene_id)

nonpcodingGR <- granges[annots$gene_biotype != "protein_coding"]
pcodingAnnots <- annots[annots$gene_biotype == "protein_coding",]
pcodingGR <- granges[annots$gene_biotype == "protein_coding"]
pcodingGR <- resize(pcodingGR, width=(width(pcodingGR) + 10000), fix="center")
dirtyPCodingGenes <- pcodingAnnots[queryHits(findOverlaps(pcodingGR, nonpcodingGR, select="all", ignore.strand=T)),"ensembl_gene_id"]
dirtyPCodingIds <- annots[annots$ensembl_gene_id %in% dirtyPCodingGenes,"ensembl_transcript_id"]

codingIds <- annots[annots$transcript_biotype == "protein_coding","ensembl_transcript_id"]
mitoIds <- annots[annots$chromosome_name == "MT","ensembl_transcript_id"]
lincIds <- annots[annots$gene_biotype == "lincRNA","ensembl_transcript_id"]

refCodingIds  <- codingIds[!(codingIds %in% mitoIds) & !(codingIds %in% dirtyPCodingIds)]
mitoCodingIds <- codingIds[codingIds %in% mitoIds]
cleanLincIds  <- lincIds[!(lincIds %in% snohgIds | lincIds %in% snhgIds | lincIds %in% miscIds)]
snohgLincIds  <- lincIds[lincIds %in% snohgIds]
