library("rtracklayer")
library("Rsamtools")
library("parallel")
library("biomaRt")
library("GenomicRanges")

source("./src/FLOSS_score/transcript-utils.R")
source("./src/FLOSS_score/footprint-assignment.R")
source("./src/FLOSS_score/floss.R")

source("./src/FLOSS_score/mouse-annotation.R")


options(mc.cores=8)

# Annotation file which in bed format with no reduncance in transcripts
BedFile <- "data/wgEncodeGencodeBasicVM24_chr.bed"

## Bamfiles need to be sorted and indexed
chxBamFile <- BamFile("data/RibosomeProfiling_sort.bam")

aoffsets <- data.frame(asite=c(11,11,11,11,12,12), row.names=seq(26,31)) # offset determined by Ribocode software

# for Samples
Bed <- import(BedFile, format="BED")
Bed$name <- gsub("\\.[[:digit:]]","" ,Bed$name ) # remove version of transcript

Size <- regionCountFrame(countSizes(defaultInsets, Bed))
write.csv(Size, "results/sizes.txt", row.names=TRUE)

Chx <- regionCountFrame(countAligns(asiteOffsets = aoffsets, insets = defaultInsets, bamfile = chxBamFile, trxBed = Bed))
write.csv(Chx, "results/Chx.txt", row.names=TRUE)

chxLDists <- calcTrxRegionLengthDists(bamfile = chxBamFile, trxBed = Bed)
writeRegionLengthDists(chxLDists, "results/chxLDists")

###########

chxLDists <- readRegionLengthDists("results/chxLDists")


chxRef <- colSums(chxLDists$cds[refCodingIds,], na.rm = TRUE)
write.csv(chxRef, "results/chx-ref-ldist.txt", row.names = TRUE)

chxLDFloss <- flossRegionLengthDists( chxLDists, chxRef )
chxFloss <- flossRegionScores( chxLDFloss )
write.csv(chxFloss, "results/chx-floss.txt", row.names=TRUE)
