library("biomaRt")
library("GenomicRanges")
library("boot")

source("./src/FLOSS_score/transcript-utils.R")
source("./src/FLOSS_score/footprint-assignment.R")
source("./src/FLOSS_score/floss.R")
source("./src/FLOSS_score/plot-utils.R")

source("./src/FLOSS_score/mouse-annotation.R")

cdist <- function(ldists) { normLDist(colSums(ldists, na.rm=TRUE)) }

lengthLevels <- seq(defaultLengthMin, defaultLengthMax)

RefLDist <- normLDist(read.csv("results/chx-ref-ldist.txt", check.names=F, row.names=1)[,1])
chxLDists <- readRegionLengthDists("results/chxLDists")
rownames(chxLDists$cds) <- gsub("\\.[[:digit:]]*","" ,rownames(chxLDists$cds) )
rownames(chxLDists$utr5) <- gsub("\\.[[:digit:]]*","" ,rownames(chxLDists$utr5) )
rownames(chxLDists$utr3) <- gsub("\\.[[:digit:]]*","" ,rownames(chxLDists$utr3) )
rownames(chxLDists$trx) <- gsub("\\.[[:digit:]]*","" ,rownames(chxLDists$trx) )

LDistCdses <- chxLDists$cds[rownames(chxLDists$cds) %in% refCodingIds,]
LDistUtr5s <- chxLDists$utr5[row.names(chxLDists$utr5) %in% refCodingIds,]
LDistLincs <- chxLDists$trx[row.names(chxLDists$trx) %in% cleanLincIds,]
LDistCdses <- chxLDists$cds[row.names(chxLDists$cds) %in% mitoCodingIds,]

CdsDist <- cdist(LDistCdses)

pdf("./results/examples-rplot.pdf")
plot(lengthLevels, CdsDist, type="l", col=lighten(solarGrey01), lwd=4,
     xlim=c(26,34), ylim=c(0,0.6), xlab="Fragment Length", main = "LincRNA")
lines(lengthLevels, cdist(LDistLincs), type="l", col=solarMagenta, lwd=2)

plot(lengthLevels, CdsDist, type="l", col=lighten(solarGrey01), lwd=4,
     xlim=c(26,34), ylim=c(0,0.5), xlab="Fragment Length", main = "5' UTR")
lines(lengthLevels, cdist(LDistUtr5s), type="l", col=solarRed, lwd=2)

dev.off()

# Write data tables
# write.csv(hg38_NY5RefCodingCdses,  "results/10_FLOSS_score/tables/ldist-hg38_NY5-refcoding-cds.txt")
# write.csv(hg38_NY5Terc,            "results/10_FLOSS_score/tables/ldist-hg38_NY5-terc-trx.txt")
# write.csv(hg38_NY5Vault,           "results/10_FLOSS_score/tables/ldist-hg38_NY5-vault-trx.txt")
# write.csv(hg38_NY5MitoCdses,       "results/10_FLOSS_score/tables/ldist-hg38_NY5-mito-cds.txt")
# write.csv(hg38_NY5Snhg5,           "results/10_FLOSS_score/tables/ldist-hg38_NY5-snhg5-trx.txt")
# write.csv(Lincs,           "results/10_FLOSS_score/tables/ldist-hg38_NY5-linc-trx.txt")
# write.csv(hg38_NY5RefCodingUtr5s,  "results/10_FLOSS_score/tables/ldist-hg38_NY5-refcoding-utr5.txt")
# write.csv(hg38_NY5HIVCDS,  "results/10_FLOSS_score/tables/ldist-hg38_NY5-hiv-cds.txt")
# write.csv(hg38_NY5HIVLTR,  "results/10_FLOSS_score/tables/ldist-hg38_NY5-hiv-ltr.txt")
# 
# write.csv(rbind(refCodingCdses  = cdist(hg38_NY5RefCodingCdses),
#                 cleanLincs      = cdist(hg38_NY5Lincs),
#                 refCodingUtr5s  = cdist(hg38_NY5RefCodingUtr5s),
#                 terc            = cdist(hg38_NY5Terc),
#                 vault           = cdist(hg38_NY5Vault),
#                 snhg5           = cdist(hg38_NY5Snhg5),
#                 hivCds          = cdist(hg38_NY5HIVCDS),
#                 hivLtr          = cdist(hg38_NY5HIVLTR)),
#           "results/FLOSS_score/tables/ldist-hg38_NY5.txt")
