library("Rsamtools")
library("biomaRt")

ensembl <- useMart("ENSEMBL_MART_ENSEMBL", dataset="mmusculus_gene_ensembl", host="uswest.ensembl.org")

annots <- getBM(attributes=c("ensembl_gene_id", "ensembl_transcript_id", "gene_biotype", "transcript_biotype",
                "chromosome_name", "start_position", "end_position", "strand", "description", "external_gene_name"),
                mart=ensembl)

granges <- GRanges(seqnames = annots$chromosome_name,
                   ranges=IRanges(start = annots$start_position, end = annots$end_position),
                   strand = ifelse(annots$strand < 0, "-", "+"))

snornaGR <- granges[annots$gene_biotype == "snoRNA",]
snohgGenes <- annots[queryHits(findOverlaps(granges, snornaGR, select="all")),"ensembl_gene_id"]
snohgIds <- annots[annots$ensembl_gene_id %in% snohgGenes,"ensembl_transcript_id"]

nonlincGR <- granges[annots$gene_biotype != "lincRNA",]
lincAnnots <- annots[annots$gene_biotype == "lincRNA",]
lincGR <- granges[annots$gene_biotype == "lincRNA",]
lincGR <- resize(lincGR, width=(width(lincGR) + 10000), fix="center")
dirtyLincGenes <- lincAnnots[queryHits(findOverlaps(lincGR, nonlincGR, select="all", ignore.strand=T)),"ensembl_gene_id"]
dirtyLincIds <- annots[annots$ensembl_gene_id %in% dirtyLincGenes,"ensembl_transcript_id"]

nonpcodingGR <- granges[annots$gene_biotype != "protein_coding"]
pcodingAnnots <- annots[annots$gene_biotype == "protein_coding",]
pcodingGR <- granges[annots$gene_biotype == "protein_coding"]
pcodingGR <- resize(pcodingGR, width=(width(pcodingGR) + 10000), fix="center")
dirtyPCodingGenes <- pcodingAnnots[queryHits(findOverlaps(pcodingGR, nonpcodingGR, select="all", ignore.strand=T)),"ensembl_gene_id"]
dirtyPCodingIds <- annots[annots$ensembl_gene_id %in% dirtyPCodingGenes,"ensembl_transcript_id"]

codingIds <- annots[annots$transcript_biotype == "protein_coding","ensembl_transcript_id"]
mitoIds <- annots[annots$chromosome_name == "MT","ensembl_transcript_id"]
lincIds <- annots[annots$gene_biotype == "lincRNA","ensembl_transcript_id"]
miscIds <- annots[annots$transcript_biotype == "misc_RNA" & !grepl("^Gm", annots$external_gene_id),"ensembl_transcript_id"]

refCodingIds <- codingIds[!(codingIds %in% mitoIds) & !(codingIds %in% dirtyPCodingIds)]
mitoCodingIds <- codingIds[codingIds %in% mitoIds]
cleanLincIds <- lincIds[!(lincIds %in% dirtyLincIds)]
