params.bam = "data/*{.bam,.bam.bai}"
params.gff = "data/*.gtf"
params.length = "25,35"
params.th = "0.5"

log.info "bam files : ${params.bam}"

Channel
  .fromFilePairs( params.bam )
  .ifEmpty { error "Cannot find any bam files matching: ${params.bam}" }
  .set { bam_files }
Channel
  .fromPath( params.gff )
  .ifEmpty { error "Cannot find any gff files matching: ${params.gff}" }
  .set { gff_files }

process ribotish_quality {
  tag "$file_id"
  publishDir "results/quality/", mode: 'copy'

  input:
  set file_id, file(bam) from bam_files
  file gff from gff_files.collect()

  output:
  set file_id, "*" into quality

  script:
  tis_parameters = ""
  if (bam =~ /Harr/) {
    tis_parameters = "-t"
  }
"""
ribotish quality -b ${bam[0]} \
                 -g ${gff} \
                 -p ${task.cpus} \
                 -l ${params.length} \
                 --th ${params.th} \
                 ${tis_parameters}
"""
}
